//Удаленное выполнение команды
function [ExecuteCode,..//Код выполнения команды
          СommandMessages,..//Сообщения от выполненной команды
          errorRemoteExecute,..//Ошибка удаленного запуска
          errorRemoteExecuteNumber,..//Номер ошибки
          errorRemoteExecuteLine,..//Строка, в которой возникла ошибка
          errorRemoteExecuteFunction,..//Функция, в которой возникла ошибка
          connectedInformation..//Информация о соединении
          ]=remoteExecCommand(NodeIPExecute,..//IP узла, на котором необходимо выполнить команду
                              NodePortExecute,..//Порт узла, на котором необходимо выполнить команду
                              ExecuteCommandName,..//Имя выполняемой команды
                              ExecuteCommandArguments,..//Аргументы выполняемой команды
                              FoneModeExecute..//Запуск в фоновом режиме
                              )
    //Проверяем аргументы
    nArgs = argn(2)//Число аргументов
    if (nArgs < 3) || (nArgs > 5) then
        error('Function remoteExecCommand takes 3, 4 or 5 arguments');
    elseif nArgs == 3 then
        ExecuteCommandArguments = [];//Нет аргументов командной строки
        FoneModeExecute = %f;//Нет фонового режима
    elseif nArgs == 4 then
        FoneModeExecute = %f;//Нет фонового режима
    end
    
    //Проверяем тип данных аргументов
    if (type(NodeIPExecute) ~= 10) ||..
       (size(NodeIPExecute,'*') > 1) then//Проверяем тип IP узла
        error('The first argument of function remoteExecCommand must be string');
    end
    typeNodePortExecute = type(NodePortExecute)//Тип порта узла
    if (typeNodePortExecute ~= 10) &&..
       ((typeNodePortExecute ~= 1) ||..
        isempty(NodePortExecute)) ||..
       (size(NodePortExecute,'*') > 1) then//Проверяем тип порта узла
       error('The second argument of function remoteExecCommand must be string or integer');
    end
    if (type(ExecuteCommandName) ~= 10) ||..
       (size(ExecuteCommandName,'*') > 1) then//Проверяем тип имени запускаемой команды
        error('The third argument of function remoteExecCommand must be string');
    end
    if (type(ExecuteCommandArguments) ~= 10) &&..
       ~isempty(ExecuteCommandArguments) then//Проверяем тип имен аргуентов выполняемой команды
        error('The forth argument of function remoteExecCommand must be string or matrix of string');
    end
    if (type(FoneModeExecute) ~= 4) ||..
       (size(FoneModeExecute,'*') > 1) then//Проверяем тип аргумента фонового режима
        error('The fifth argument of function remoteExecCommand must be boolean');
    end
    
    //Устанавливаем связь с удаленным компьютером
    try
        SOCKET_open('exesCommandSocket',..
                    NodeIPExecute,..
                    NodePortExecute);//Открываем сокет для удаленного выполнения команды
    catch
        ExecuteCode = 1;//Подключение не удалось (узел выключен или защищен от подключения административными правами)
        СommandMessages = [];//Пустой результат выполнения команды
        [errorRemoteExecute,..//Ошибка удаленного запуска
         errorRemoteExecuteNumber,..//Номер ошибки
         errorRemoteExecuteLine,..//Строка, в которой возникла ошибка
         errorRemoteExecuteFunction..//Функция, в которой возникла ошибка
         ] = lasterror(%t);//Информация об ошибке
        connectedInformation = 'Couldn''t connection to node ' + NodeIPExecute + ' port ' + string(NodePortExecute);//Невозможность подключиться к ноду
        
        return;//Выходим из функции 
    end
    
    //Формируем команду
    FullExecuteCommand = '{' + ExecuteCommandName + '}';//Полная выполняемая команда
    if size(ExecuteCommandArguments,'*') > 0 then//Добавляем при необходимости командные аргументы
        FullExecuteCommand = FullExecuteCommand + ' ' +..
                             strcat('{' + ExecuteCommandArguments + '}', ' ');//Полная выполняемая команда
    end
    if FoneModeExecute then//Добавляем при необходимости запуск в фоновом режиме
        FullExecuteCommand = FullExecuteCommand + ' &'; 
    end
    
    //Отправляем команду на удаленный компьютер
    SOCKET_write('exesCommandSocket',FullExecuteCommand);
    
    //Получаем результат выполнения отправленной команды
    SocketInfo = []//Информация c соединения
    while isempty(SocketInfo)//Ожидаем информацию с соединения
        SocketInfo = SOCKET_read('exesCommandSocket')//Получаем информацию с соединения
    end
    СommandMessages = SocketInfo($-1:-1:1);//Результат выполнения команды
    connectedInformation = SocketInfo($);//Информация о соединении
    
    //Закрываем сокет
    SOCKET_close('exesCommandSocket');
    
    //Обрабатываем информацию от выполненных команд
    ind = strindex(СommandMessages(1), ':')(1);//Индекс первого вхождения двоеточия в первую строку сообщений
    if part(СommandMessages(1), ind - 1) == 's' then
        СommandMessages = [part(СommandMessages(1), 1:ind);..
                           СommandMessages];//Добавляем заголовок в список сообщений от команды
        СommandMessages(2) = part(СommandMessages(2), (ind + 2):$);//Корректируем первое сообщение
    end
    
    //Выводим сообщение о несуществующей ошибке
    errorRemoteExecute = [];//Ошибка удаленного запуска
    errorRemoteExecuteNumber = 0;//Номер ошибки
    errorRemoteExecuteLine = 0;//Строка, в которой возникла ошибка
    errorRemoteExecuteFunction = "";//Функция, в которой возникла ошибка
    
    //Полуаем код выполнения команды
    etalonHead = 'Exec Server Error: ';//Факт ошибки хапуска команды
    lenEtanolHead = length(etalonHead);//длина строки факта ошибки запуска команды
    if part(СommandMessages, 1:lenEtanolHead) == etalonHead then
        ExecuteCode = 2;//Невозможность выполнить команду на узле (подключиться к узлу удалось)
    else
        ExecuteCode = 0;//Нет ошибок выполнения команды
    end
endfunction
